clear

setpath_dynare

global M_ oo_ changes_names changes_vec

modnam = 'two_sector_vcu';
modnamstar= 'two_sector_vcu_binding';

modnam_one_sector = 'one_sector_vcu';
modnamstar_one_sector= 'one_sector_vcu_binding';

capital_irreversibility_switch = 1;

sensitivity_switch_minimum_scale = 0;

slide_switch = 0;

constraint = 'in<-in_ss';
constraint_relax = 'lambdai<-0.0000001';

maxiter = 20;

irf_switch = 0;  % set to 1 to run an IRF, set to 0 to run a simulation based on teh SIR model

paramfile_two_sector_vcu

if irf_switch
    % parameter file to get the persistence parameter, needed to form a matrix
    % below
    
    shockssequence = -0.01;
    irfshock = 'eps_l1';
    nperiods = 100;
    
    % rho = 1/(elast-1) --- go with elast = 2, in other worsds, elast =
    % (1+rho)/rho
    
    if sensitivity_switch_minimum_scale
        changes_names = char('rhop',...
            'chip');
        changes_vec =       [1
            l1_ss*6/10];
        
    else
        changes_names = char('rhop');
        changes_vec =       [1];
    end
    
    [zdatalinear, zdatass, oobase_, Mbase_ ] = ...
        solve_no_constraint(modnam,...
        shockssequence,irfshock,nperiods);
    
    % rho = 1/(elast-1) --- go with elast = 1/3; elast = (1+rho)/rho
    if sensitivity_switch_minimum_scale
        changes_names = char('rhop','chip');
        changes_vec =       [-3/2
            l1_ss*6/10];
        
    else
        changes_names = char('rhop');
        changes_vec =       [-3/2];
    end
    
    [zdatalinear2, zdatass2, oobase2_, Mbase2_ ] = ...
        solve_no_constraint(modnam,...
        shockssequence,irfshock,nperiods);
    
    
    prefix1 = 's1_';
    prefix2 = 's2_';
    for this_var = 1:Mbase_.endo_nbr
        eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_irf=zdatalinear(:,this_var);'])
        eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_ss=zdatass(this_var);'])
        
        eval([prefix2,deblank(Mbase_.endo_names(this_var,:)),'_irf=zdatalinear2(:,this_var);'])
        eval([prefix2,deblank(Mbase_.endo_names(this_var,:)),'_ss=zdatass2(this_var);'])
        
    end
    
    
    titlelist = char('Output','Consumption',...
        'Investment', 'Sector 1 Labor',...
        'Sector-2 Value Added', 'Capacity Utilization');
    
    
    line1 = 100*[ s1_y_irf/s1_y_ss, s1_c_irf/s1_c_ss,...
        s1_in_irf/s1_in_ss, s1_l1_irf,...
        s1_v2_irf/s1_v2_ss, s1_u_irf];
    
    line2 = 100*[ s2_y_irf/s2_y_ss, s2_c_irf/s1_c_ss,...
        s2_in_irf/s2_in_ss, s2_l1_irf,...
        s2_v2_irf/s2_v2_ss, s2_u_irf];
    
    percent = 'Percent';
    ppt = 'Perc. Point';
    level = 'Level';
    ylabels = char(percent,percent,...
        percent,percent,...
        percent,percent);
    figlabel = '';
    
    
    
    legendlist = char('Elasticity = 2','Elasticity = 0.3');
    
    
    
    makechart(titlelist,legendlist,figlabel,ylabels,line1,line2);
    
else
    
    eval(['dynare ',modnam,' noclearall'])
    
    paramfile_two_sector_vcu;
    
    
    
    % call SIR model
    
    months = 12;
    months_lockdown = 0;
    
    effectiveness_share = 0.8;  % irrelevant without a lockdown
    share1_lockdown = 0;
    share2_lockdown = 0;
    share3_lockdown = 0;
    
    share_working_while_infected = 0.4;
    
    N1 = l1_ss;
    N2 = l2_ss;
    
    % run as daily model
    betap_base = 0.2;
    
    gammap1 = 1/20;    % recovery rate
    gammap2 = gammap1;
    gammap3 = gammap1;
    
    omegap1 = 0;       % death rate -- abstract from the effects of deaths for now
    omegap2 = omegap1;
    omegap3 = omegap1;
    
    
    [S1,R1,I1,S2,R2,I2,S3,I3,R3]=SIRmodel_3groups_func(months,...
        months_lockdown,effectiveness_share,share1_lockdown,share2_lockdown,share3_lockdown,...
        N1,N2,betap_base,gammap1,gammap2,gammap3,omegap1,omegap2,omegap3);
    
    % temporal aggregation of SIR model from days to month
    
    
    I1_month = mean(reshape(I1',30,months));
    I2_month = mean(reshape(I2',30,months));
    
    
    
    
    % path for the exogenous variable
    paramfile_two_sector_vcu
    
    % take off the infected folks from the labor force
    l1_path =  - I1_month'*(1-share_working_while_infected);
    l2_path =  - I2_month'*(1-share_working_while_infected);
    
    l1_path_lag = [0; l1_path(1:end-1)];
    l2_path_lag = [0; l2_path(1:end-1)];
    
    % define matrix needed to calculate the sizes of the shocks
    amat = diag(rhop_l*ones(months,1));
    
    % translate the path for a into the path for the shocks m
    m_path = l1_path-amat*l1_path_lag;
    n_path = l2_path-amat*l2_path_lag;
    
    
    % put the shocks on the vector of predetermined conditions
    m_pos_vec = zeros(months,1);
    n_pos_vec = zeros(months,1);
    
    endo_names = cellstr(M_.endo_names);
    for m_indx = 1:months
        this_m = ['m',num2str(m_indx)];
        this_n = ['n',num2str(m_indx)];
        m_pos_vec(m_indx)=find(strcmp(this_m, endo_names));
        n_pos_vec(m_indx)=find(strcmp(this_n, endo_names));
        
    end
    
    init = zeros(M_.endo_nbr,1);
    init(m_pos_vec)=m_path;
    init(n_pos_vec)=n_path;
    
    % now get the response to the initial conditions
    shockssequence = 0;
    irfshock = '';
    nperiods = months;
    
    if sensitivity_switch_minimum_scale
        changes_names = char('rhop','chip');
        changes_vec =       [-3/2
            l1_ss*6/10];
        
    else
        changes_names = char('rhop');
        changes_vec =       [-3/2];
    end
    
    if capital_irreversibility_switch
        
        [zdatalinear, zdatapiecewise, zdatass, oobase_ Mbase_] = ...
            solve_one_constraint(modnam,modnamstar,...
            constraint, constraint_relax,...
            shockssequence,irfshock,nperiods,maxiter,init)
        
        zdatalinear = zdatapiecewise;
        
    else
        
        [zdatalinear, zdatass, oobase_, Mbase_ ] = ...
            solve_no_constraint(modnam,...
            shockssequence,irfshock,nperiods,init);
    end
    
    %% now do it again but for a one sector model
    N1 = 0;
    N2 = l1_ss+l2_ss;
    
    
    [~,~,~,~,~,I2_one_sector]=SIRmodel_3groups_func(months,...
        months_lockdown,effectiveness_share,share1_lockdown,share2_lockdown,share3_lockdown,...
        N1,N2,betap_base,gammap1,gammap2,gammap3,omegap1,omegap2,omegap3);
    
    
    
    I2_one_sector_month = mean(reshape(I2_one_sector',30,months));
    
    
    
    l2_path =  - I2_one_sector_month'*(1-share_working_while_infected);
    l2_path_lag = [0; l2_path(1:end-1)];
    
    
    n_path = l2_path-amat*l2_path_lag;
    
    eval(['dynare ',modnam_one_sector,' noclearall'])
    
    endo_names = cellstr(M_.endo_names);
    for m_indx = 1:months
        
        this_n = ['n',num2str(m_indx)];
        n_pos_vec(m_indx)=find(strcmp(this_n, endo_names));
        
    end
    
    init = zeros(M_.endo_nbr,1);
    init(n_pos_vec)=n_path;
    
    
    
    if capital_irreversibility_switch
        
        [zdatalinear2, zdatapiecewise2, zdatass2, oobase2_ Mbase2_] = ...
            solve_one_constraint(modnam_one_sector,modnamstar_one_sector,...
            constraint, constraint_relax,...
            shockssequence,irfshock,nperiods,maxiter,init)
        
        zdatalinear2 = zdatapiecewise2;
        
    else
        
        [zdatalinear2, zdatass2, oobase2_, Mbase2_ ] = ...
            solve_no_constraint(modnam_one_sector,...
            shockssequence,irfshock,nperiods,init);
    end
    
    
    prefix1 = 's1_';
    prefix2 = 's2_';
    for this_var = 1:Mbase_.endo_nbr
        eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_irf=zdatalinear(:,this_var);'])
        eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_ss=zdatass(this_var);'])
    end
    
    for this_var = 1:Mbase2_.endo_nbr
        eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_irf=zdatalinear2(:,this_var);'])
        eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_ss=zdatass2(this_var);'])
    end
    
    
    
    if slide_switch
        %% Aggregate figure
        
        
        titlelist = char('Infected, Group 1 and 2 Total','Infected');
        
        
        line1 = 100*[ I2_one_sector_month'/(l1_ss+l2_ss), (I1_month')/(l1_ss+l2_ss)];
        
        line2 = 100*[ nan*I2_one_sector_month', I2_month'/(l1_ss+l2_ss)];
        
        percent = '% dev. from steady state';
        ppt = 'Perc. Point';
        level = 'Level';
        percent_population = '% of population'
        ylabels = char(percent_population,percent_population);
        figlabel = '';
        legendlist = char('Two-sector model','One-sector model');
        makechart_months_distancing2(titlelist,legendlist,figlabel,ylabels,line1,line2);
        
        printpref_slide
        
        if sensitivity_switch_minimum_scale
            print -depsc2 figure1_slide_do_nothing_1_sector_vs_2_sectors_case2.eps
        else
            print -depsc2 figure1_slide_do_nothing_1_sector_vs_2_sectors.eps
        end
        
        %% aggregate figure 
        titlelist = char(...
            'Output, Total','Capacity Utilization',...
            'Consumption','Investment');
        
        
        line1 = 100*[ ...
            s1_y_irf/s1_y_ss, s1_u_irf/s1_u_ss,...
            s1_c_irf/s1_c_ss, s1_in_irf/s1_in_ss];
        
        line2 = 100*[ ...
            s2_y_irf/s2_y_ss, s2_u_irf/s2_u_ss,...
            s2_c_irf/s2_c_ss, s2_in_irf/s2_in_ss];
        
        percent = '% dev. from steady state';
        ppt = 'Perc. Point';
        level = 'Level';
        percent_population = '% of population'
        ylabels = char(...
            percent,percent,...
            percent,percent);
        figlabel = '';
        legendlist = char('Two-sector model','One-sector model');
        makechart(titlelist,legendlist,figlabel,ylabels,line1,line2);
        subplot(2,2,3)
        xlabel('Months')
        subplot(2,2,4)
        xlabel('Months')
        printpref_slide
        
        if sensitivity_switch_minimum_scale
            print -depsc2 figure2_slide_do_nothing_1_sector_vs_2_sectors_case2.eps
        else
            print -depsc2 figure2_slide_do_nothing_1_sector_vs_2_sectors.eps
        end
        %% sectoral detail
        
        titlelist = char(...
            'Labor, Sector 1', 'Labor, Sector 2',...
            'Value Added, Sector 1', 'Value Added, Sector 2');
        
        
        line1 = 100*[ s1_l1_irf/s1_l1_ss, s1_l2_irf/s1_l2_ss,...
            s1_v1_irf/s1_v1_ss, s1_v2_irf/s1_v2_ss...
            ];
        
        
        
        percent = '% dev. from steady state';
        ppt = 'Perc. Point';
        level = 'Level';
        percent_group= '% of group size'
        ylabels = char(percent_group,percent_group,...
            percent,percent,...
            percent,percent);
        figlabel = '';
        legendlist = char('');
        makechart(titlelist,legendlist,figlabel,ylabels,line1);
        subplot(2,2,3)
        xlabel('Months')
        subplot(2,2,4)
        xlabel('Months')
        printpref_slide
        
        if sensitivity_switch_minimum_scale
            print -depsc2 figure3_slide_do_nothing_1_sector_vs_2_sectors_case2.eps
        else
            print -depsc2 figure3_slide_do_nothing_1_sector_vs_2_sectors.eps
        end
    else % this is when we are not making figure for slides
        %% Aggregate figure
        titlelist = char('Infected, Group 1 and 2 Total','Infected',...
            'Output, Total','Capacity Utilization',...
            'Consumption','Investment');
        
        
        line1 = 100*[ I2_one_sector_month'/(l1_ss+l2_ss), (I1_month')/(l1_ss+l2_ss), ...
            s1_y_irf/s1_y_ss, s1_u_irf/s1_u_ss,...
            s1_c_irf/s1_c_ss, s1_in_irf/s1_in_ss];
        
        line2 = 100*[ nan*I2_one_sector_month', I2_month'/(l1_ss+l2_ss),...
            s2_y_irf/s2_y_ss, s2_u_irf/s2_u_ss,...
            s2_c_irf/s2_c_ss, s2_in_irf/s2_in_ss];
        
        percent = '% dev. from steady state';
        ppt = 'Perc. Point';
        level = 'Level';
        percent_population = '% of population'
        ylabels = char(percent_population,percent_population,...
            percent,percent,...
            percent,percent);
        figlabel = '';
        legendlist = char('Two-sector model','One-sector model');
        makechart_months_distancing2(titlelist,legendlist,figlabel,ylabels,line1,line2);
        
        printpref
        
        if sensitivity_switch_minimum_scale
            print -depsc2 figure1_do_nothing_1_sector_vs_2_sectors_case2.eps
        else
            print -depsc2 figure1_do_nothing_1_sector_vs_2_sectors.eps
        end
        %% sectoral detail
        
        titlelist = char('Infected, Group 1','Infected, Group 2',...
            'Labor, Sector 1', 'Labor, Sector 2',...
            'Value Added, Sector 1', 'Value Added, Sector 2');
        
        
        line1 = 100*[ I1_month'/s1_l1_ss, I2_month'/s1_l2_ss, ...
            s1_l1_irf/s1_l1_ss, s1_l2_irf/s1_l2_ss,...
            s1_v1_irf/s1_v1_ss, s1_v2_irf/s1_v2_ss...
            ];
        
        
        
        percent = '% dev. from steady state';
        ppt = 'Perc. Point';
        level = 'Level';
        percent_group= '% of group size'
        ylabels = char(percent_group,percent_group,...
            percent,percent,...
            percent,percent);
        figlabel = '';
        legendlist = char('');
        makechart(titlelist,legendlist,figlabel,ylabels,line1);
        subplot(3,2,5)
        xlabel('Months')
        subplot(3,2,6)
        xlabel('Months')
        printpref
        
        if sensitivity_switch_minimum_scale
            print -depsc2 figure2_do_nothing_1_sector_vs_2_sectors_case2.eps
        else
            print -depsc2 figure2_do_nothing_1_sector_vs_2_sectors.eps
        end
        
    end
end

n_periods_average = 6;

s1_cumy = mean(s1_y_irf(1:n_periods_average))/s1_y_ss*100
s2_cumy = mean(s2_y_irf(1:n_periods_average))/s2_y_ss*100 

