clear 

setpath_dynare

global M_ oo_ changes_names changes_vec

modnam = 'two_sector_vcu';
modnamstar= 'two_sector_vcu_binding';

modnam_one_sector = 'one_sector_vcu';
modnamstar_one_sector= 'one_sector_vcu_binding';

capital_irreversibility_switch = 1;

constraint = 'in<-in_ss'; 
constraint_relax = 'lambdai<-0.0000001';

maxiter = 20;

n_periods_average = 6;

load_from_disk = 1;

if ~load_from_disk
    betap_base_vec = [0.5:-0.01:0.05];
    for ibase = 1:length(betap_base_vec)

        eval(['dynare ',modnam,' noclearall'])

        paramfile_two_sector_vcu;

        % call SIR model

        months = 6;
        months_lockdown = 0;

        effectiveness_share = 0.8;  % irrelevant without a lockdown
        share1_lockdown = 0;
        share2_lockdown = 0;
        share3_lockdown = 0;   

        share_working_while_infected = 0.4;

        N1 = l1_ss;
        N2 = l2_ss;

        % run as daily model
        betap_base = betap_base_vec(ibase);

        gammap1 = 1/20;    % recovery rate
        gammap2 = gammap1;
        gammap3 = gammap1;

        omegap1 = 0;       % death rate -- abstract from the effects of deaths for now
        omegap2 = omegap1;
        omegap3 = omegap1;


        [S1,R1,I1,S2,R2,I2,S3,I3,R3]=SIRmodel_3groups_func(months,...
                months_lockdown,effectiveness_share,share1_lockdown,share2_lockdown,share3_lockdown,...
                N1,N2,betap_base,gammap1,gammap2,gammap3,omegap1,omegap2,omegap3);

        % temporal aggregation of SIR model from days to month
        I1_month = mean(reshape(I1',30,months));
        I2_month = mean(reshape(I2',30,months));
        I3_month = mean(reshape(I3',30,months));

        
        % path for the exogenous variable
        paramfile_two_sector_vcu

        % take off the infected folks from the labor force
        l1_path =  - I1_month'*(1-share_working_while_infected);
        l2_path =  - I2_month'*(1-share_working_while_infected);

        l1_path_lag = [0; l1_path(1:end-1)];
        l2_path_lag = [0; l2_path(1:end-1)];

        % define matrix needed to calculate the sizes of the shocks
        amat = diag(rhop_l*ones(months,1));

        % translate the path for a into the path for the shocks m
        m_path = l1_path-amat*l1_path_lag;
        n_path = l2_path-amat*l2_path_lag;


        % put the shocks on the vector of predetermined conditions
        m_pos_vec = zeros(months,1);
        n_pos_vec = zeros(months,1);

        endo_names = cellstr(M_.endo_names);
        for m_indx = 1:months
            this_m = ['m',num2str(m_indx)];
            this_n = ['n',num2str(m_indx)];
            m_pos_vec(m_indx)=find(strcmp(this_m, endo_names));
            n_pos_vec(m_indx)=find(strcmp(this_n, endo_names));
        end
        init = [];
        init = zeros(M_.endo_nbr,1);
        init(m_pos_vec)=m_path;
        init(n_pos_vec)=n_path;

        % now get the response to the initial conditions
        shockssequence = 0;  
        irfshock = '';
        nperiods = months;

        changes_names = char('rhop','chip');
        changes_vec =       [-3/2
                             l1_ss*6/10];

        if capital_irreversibility_switch

        [zdatalinear, zdatapiecewise, zdatass, oobase_ Mbase_] = ...
        solve_one_constraint(modnam,modnamstar,...
        constraint, constraint_relax,...
        shockssequence,irfshock,nperiods,maxiter,init)

        zdatalinear = zdatapiecewise;

        else

        [zdatalinear, zdatass, oobase_, Mbase_ ] = ...
            solve_no_constraint(modnam,...
            shockssequence,irfshock,nperiods,init);
        end

        %% now do it again but for a one sector model
        N1 = 0;
        N2 = l1_ss+l2_ss;

        [~,~,~,~,~,I2_one_sector]=SIRmodel_3groups_func(months,...
                months_lockdown,effectiveness_share,share1_lockdown,share2_lockdown,share3_lockdown,...
                N1,N2,betap_base,gammap1,gammap2,gammap3,omegap1,omegap2,omegap3);

        I2_one_sector_month = mean(reshape(I2_one_sector',30,months));

        l2_path =  - I2_one_sector_month'*(1-share_working_while_infected);
        l2_path_lag = [0; l2_path(1:end-1)];


        n_path = l2_path-amat*l2_path_lag;

        eval(['dynare ',modnam_one_sector,' noclearall'])

        endo_names = cellstr(M_.endo_names);
        for m_indx = 1:months

            this_n = ['n',num2str(m_indx)];
            n_pos_vec(m_indx)=find(strcmp(this_n, endo_names));

        end

        init = zeros(M_.endo_nbr,1);
        init(n_pos_vec)=n_path;

        if capital_irreversibility_switch

        [zdatalinear2, zdatapiecewise2, zdatass2, oobase2_ Mbase2_] = ...
        solve_one_constraint(modnam_one_sector,modnamstar_one_sector,...
        constraint, constraint_relax,...
        shockssequence,irfshock,nperiods,maxiter,init)

        zdatalinear2 = zdatapiecewise2;

        else

        [zdatalinear2, zdatass2, oobase2_, Mbase2_ ] = ...
            solve_no_constraint(modnam_one_sector,...
            shockssequence,irfshock,nperiods,init);
        end

        prefix1 = 's1_';
        prefix2 = 's2_';
        for this_var = 1:Mbase_.endo_nbr
            eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_irf=zdatalinear(:,this_var);'])
            eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_ss=zdatass(this_var);'])   
        end 

        for this_var = 1:Mbase2_.endo_nbr
            eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_irf=zdatalinear2(:,this_var);'])
            eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_ss=zdatass2(this_var);'])   
        end
        s1_cumy(ibase,1) = mean(s1_y_irf(1:n_periods_average))/s1_y_ss;
        s2_cumy(ibase,1) = mean(s2_y_irf(1:n_periods_average))/s2_y_ss;   
        s1_maxI(ibase,1) = max(I1_month+I2_month+I3_month);
    end   
    

    
    


save sensitivity_results_six_months_chip_6_10 betap_base_vec s1_cumy s2_cumy

else

%%

figure; subplot(2,1,1)
load sensitivity_results_six_months

plot(betap_base_vec,-100*s1_cumy,'xb')
hold on;plot(betap_base_vec,-100*s2_cumy,'or')
xlabel('Contact rate \beta')
ylabel('Average output loss over 6 months')
title('Contact Rate and Cumulative Output Loss')

legend('Two-Sector Model','One-Sector Model')

subplot(2,1,2)

load sensitivity_results_six_months_chip_6_10

plot(betap_base_vec,-100*s1_cumy,'xb')
hold on;plot(betap_base_vec,-100*s2_cumy,'or')
xlabel('Contact rate \beta')
ylabel('Average output loss over 6 months')
title('A Higher Minimum Scale Parameter For Sector 2')

%legend('Two-Sector Model','One-Sector Model')

printpref
print -depsc2 figure_beta_sensitivity.eps

end
